==> XoopsHP1.1.zip: XoopsHP1.1/module/XoopsHP/language/english/modinfo.php <==
<?php
//  ------------------------------------------------------------------------ //
//             --  XoopsHP Module --       Xoops e-Learning System           //
//                     Copyright (c) 2005 SUDOW-SOKEN                        //
//                      <http://www.mailpark.co.jp/>                         //
//  ------------------------------------------------------------------------ //
//               Based on XoopsHP1.01 by Yoshi, aka HowardGee.               //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //
// Module Info

define("_MI_XHP_NAME","XoopsHP");
define("_MI_XHP_DESC","Manages quizzes created by <a href='http://web.uvic.ca/hrd/hotpot/' target='_new'>HotPotatoes</a>.");
define("_MI_XHP_ADMENU","Manage Quizzes");
define("_MI_XHP_LICENSE","Hot Potatoes License");
define("_MI_XHP_LICENSE_DESC","Do you have a valid Hot Potatoes license?<br /><br />To use <a href='http://web.uvic.ca/hrd/hotpot/' target='_new'>Hot Potatoes</a> for free, you need to meet the requirements.  Please read <a href='http://www.halfbakedsoftware.com/hot_pot_licence_terms.php' target='_new'>Terms of Use for Hot Potatoes</a> for details.<br /><br /><b>Without the license, you must grant module access permission for anonymous users group so that all the quiz files are available to guest visitors to this site.</b>");
define("_MI_XHP_WELCOME_T","Title of the main page");
define("_MI_XHP_WELCOME","Welcome to the HotPotatoes quiz farm at %s");
define("_MI_XHP_DESC_T","Description in the main page");
define("_MI_XHP_DESC_N","Here you can find some challenging quizzes that are created with <a href='http://web.uvic.ca/hrd/hotpot/' target='_new'>HotPotatoes</a>.");
define("_MI_XHP_MAIL_TEACHER","Mail Instructor");
define("_MI_XHP_MAIL_USER","Mail User");
define("_MI_XHP_MAIL_OWNER","Mail Site Owner");

define("_MI_XHP_BLATEST", "Latest Tasks");
define("_MI_XHP_BRANKING", "Grand Average Ranking");
define("_MI_XHP_BCOMPLETED", "Completed Tasks Ranking");
define("_MI_XHP_BCOURSERANK", "Course Average Ranking");
?>

==> XoopsHP1.11.zip: XoopsHP1.11/module/XoopsHP/language/english/modinfo.php <==
<?php
//  ------------------------------------------------------------------------ //
//             --  XoopsHP Module --       Xoops e-Learning System           //
//                     Copyright (c) 2005 SUDOW-SOKEN                        //
//                      <http://www.mailpark.co.jp/>                         //
//  ------------------------------------------------------------------------ //
//               Based on XoopsHP1.01 by Yoshi, aka HowardGee.               //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //
// Module Info

define("_MI_XHP_NAME","XoopsHP");
define("_MI_XHP_DESC","Manages quizzes created by <a href='http://web.uvic.ca/hrd/hotpot/' target='_new'>HotPotatoes</a>.");
define("_MI_XHP_ADMENU","Manage Quizzes");
define("_MI_XHP_LICENSE","Hot Potatoes License");
define("_MI_XHP_LICENSE_DESC","Do you have a valid Hot Potatoes license?<br /><br />To use <a href='http://web.uvic.ca/hrd/hotpot/' target='_new'>Hot Potatoes</a> for free, you need to meet the requirements.  Please read <a href='http://www.halfbakedsoftware.com/hot_pot_licence_terms.php' target='_new'>Terms of Use for Hot Potatoes</a> for details.<br /><br /><b>Without the license, you must grant module access permission for anonymous users group so that all the quiz files are available to guest visitors to this site.</b>");
define("_MI_XHP_WELCOME_T","Title of the main page");
define("_MI_XHP_WELCOME","Welcome to the HotPotatoes quiz farm at %s");
define("_MI_XHP_DESC_T","Description in the main page");
define("_MI_XHP_DESC_N","Here you can find some challenging quizzes that are created with <a href='http://web.uvic.ca/hrd/hotpot/' target='_new'>HotPotatoes</a>.");
define("_MI_XHP_MAIL_TEACHER","Mail Instructor");
define("_MI_XHP_MAIL_USER","Mail User");
define("_MI_XHP_MAIL_OWNER","Mail Site Owner");
define("_MI_XHP_MAX_FILE_SIZE","Maximum Task File Size (byte)");
define("_MI_XHP_DEF_DAYS","Default days before expire");

define("_MI_XHP_BLATEST", "Latest Tasks");
define("_MI_XHP_BRANKING", "Grand Average Ranking");
define("_MI_XHP_BCOMPLETED", "Completed Tasks Ranking");
define("_MI_XHP_BCOURSERANK", "Course Average Ranking");
?>
